==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFormDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescriptionMetadata } from "./WebFormDataDescriptionMetadata";
import { WebFormDataEventArgsDescription } from "./WebFormDataEventArgsDescription";
/**
 * @hidden
 */
export let WebFormDataEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFormDataEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFormDataEventArgsDescriptionMetadata.a == null) {
                WebFormDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFormDataEventArgsDescriptionMetadata.c(WebFormDataEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebFormDataEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFormDataEventArgsDescriptionMetadata.a);
            WebFormDataDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FormDataEventArgs");
            a.item("Detail", "ExportedType:WebFormData");
        }
        static d(a) {
            WebFormDataEventArgsDescriptionMetadata.b(a);
            a.aa("WebFormDataEventArgs", () => new WebFormDataEventArgsDescription());
            a.z("WebFormDataEventArgs", WebFormDataEventArgsDescriptionMetadata.a);
        }
    }
    WebFormDataEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFormDataEventArgsDescriptionMetadata, 'WebFormDataEventArgsDescriptionMetadata');
    WebFormDataEventArgsDescriptionMetadata.a = null;
    return WebFormDataEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFormDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescriptionMetadata } from "./WebFormDataDescriptionMetadata";
import { WebFormDataEventArgsDescription } from "./WebFormDataEventArgsDescription";
/**
 * @hidden
 */
export let WebFormDataEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFormDataEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFormDataEventArgsDescriptionMetadata.a == null) {
                WebFormDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFormDataEventArgsDescriptionMetadata.c(WebFormDataEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFormDataEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFormDataEventArgsDescriptionMetadata.a);
            WebFormDataDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FormDataEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebFormData");
        }
        static d(a) {
            WebFormDataEventArgsDescriptionMetadata.b(a);
            a.ac("WebFormDataEventArgs", () => new WebFormDataEventArgsDescription());
            a.ab("WebFormDataEventArgs", WebFormDataEventArgsDescriptionMetadata.a);
        }
    }
    WebFormDataEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFormDataEventArgsDescriptionMetadata, 'WebFormDataEventArgsDescriptionMetadata');
    WebFormDataEventArgsDescriptionMetadata.a = null;
    return WebFormDataEventArgsDescriptionMetadata;
})();
